@@ -1,7 +1,7 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.16'
+__version__ = '2.0.17'
 
 import platform
 import os
@@ -24,7 +24,7 @@ from sqlalchemy import text as sql
 from pathlib import Path
 
 from pyaltt2.crypto import gen_random_str
-from pyaltt2.network import parse_host_port
+from pyaltt2.network import parse_host_port, generate_netacl
 from pyaltt2.config import load_yaml, config_value, choose_file
 from netaddr import IPNetwork
 
@@ -127,8 +127,8 @@ def load(fname=None):
                                     socket_keepalive=True)
         logger.info(
             f'CORE limits feature activated. Redis: {rhost}:{rport} db: {rdb}')
-    config['_acl'] = [IPNetwork(h) for h in config['master']['allow']] if \
-            config.get('master', {}).get('allow') else None
+    config['_acl'] = generate_netacl(config.get('master', {}).get('allow'),
+                                     default=None)
     masterkey = os.getenv('ROBOGER_MASTERKEY')
     config_value(env='ROBOGER_MASTERKEY',
                  config=config,
@@ -176,9 +176,12 @@ def load(fname=None):
     logger.debug('CORE initializing thread pool for plugins '
                  f'with max size {thread_pool_size}')
     _d.pool = ThreadPoolExecutor(max_workers=thread_pool_size)
+    logger.debug('CORE initializing database')
     init_db()
     from . import api
+    logger.debug('CORE initializing API')
     api.init()
+    logger.debug('CORE initialzation completed')
 
 
 def spawn(*args, **kwargs):
